@@ -1573,8 +1573,8 @@ class MTLFrameDto(RiotApiResponse):
     def __init__(self, events: List[dict], participantFrames: dict, timestamp: int, **kwargs):
         super().__init__(**kwargs)
         self.events: List[MTLEventDto] = list(map(lambda x: MTLEventDto(**x), events))
-        self.participantFrames: MTLParticipantFramesDto = MTLParticipantFramesDto(
-            **{f'f{k}': v for k, v in participantFrames.items()}
+        self.participantFrames: List[MTLParticipantFrameDto] = list(
+            map(lambda x: MTLParticipantFrameDto(**x), participantFrames)
         )
         self.timestamp = timestamp
 
@@ -1648,20 +1648,20 @@ class MTLDamageDto(RiotApiResponse):
         self.type = type
 
 
-class MTLParticipantFramesDto(RiotApiResponse):
-    def __init__(self, f1: dict, f2: dict, f3: dict, f4: dict, f5: dict, f6: dict, f7: dict, f8: dict, f9: dict,
-                 f10: dict, **kwargs):
-        super().__init__(**kwargs)
-        self.f1: MTLParticipantFrameDto = MTLParticipantFrameDto(**f1)
-        self.f2: MTLParticipantFrameDto = MTLParticipantFrameDto(**f2)
-        self.f3: MTLParticipantFrameDto = MTLParticipantFrameDto(**f3)
-        self.f4: MTLParticipantFrameDto = MTLParticipantFrameDto(**f4)
-        self.f5: MTLParticipantFrameDto = MTLParticipantFrameDto(**f5)
-        self.f6: MTLParticipantFrameDto = MTLParticipantFrameDto(**f6)
-        self.f7: MTLParticipantFrameDto = MTLParticipantFrameDto(**f7)
-        self.f8: MTLParticipantFrameDto = MTLParticipantFrameDto(**f8)
-        self.f9: MTLParticipantFrameDto = MTLParticipantFrameDto(**f9)
-        self.f10: MTLParticipantFrameDto = MTLParticipantFrameDto(**f10)
+# class MTLParticipantFramesDto(RiotApiResponse):
+#     def __init__(self, f1: dict, f2: dict, f3: dict, f4: dict, f5: dict, f6: dict, f7: dict, f8: dict, f9: dict,
+#                  f10: dict, **kwargs):
+#         super().__init__(**kwargs)
+#         self.f1: MTLParticipantFrameDto = MTLParticipantFrameDto(**f1)
+#         self.f2: MTLParticipantFrameDto = MTLParticipantFrameDto(**f2)
+#         self.f3: MTLParticipantFrameDto = MTLParticipantFrameDto(**f3)
+#         self.f4: MTLParticipantFrameDto = MTLParticipantFrameDto(**f4)
+#         self.f5: MTLParticipantFrameDto = MTLParticipantFrameDto(**f5)
+#         self.f6: MTLParticipantFrameDto = MTLParticipantFrameDto(**f6)
+#         self.f7: MTLParticipantFrameDto = MTLParticipantFrameDto(**f7)
+#         self.f8: MTLParticipantFrameDto = MTLParticipantFrameDto(**f8)
+#         self.f9: MTLParticipantFrameDto = MTLParticipantFrameDto(**f9)
+#         self.f10: MTLParticipantFrameDto = MTLParticipantFrameDto(**f10)
 
 
 class MTLParticipantFrameDto(RiotApiResponse):
